import {
  isUint8Array
} from "./chunk-EOHXRMVQ.js";

// src/node/fs.ts
import { mkdir, readFile, rm, stat, writeFile } from "node:fs/promises";
import { dirname, join as joinPath, normalize } from "node:path";
import process from "node:process";
function toHumanReadableFilePath(path) {
  const p = normalize(path);
  const h = process.env.HOME;
  if (h && p.startsWith(h))
    return `~${p.slice(h.length)}`;
  return p;
}
async function exists(path) {
  try {
    await stat(path);
  } catch (err) {
    return false;
  }
  return true;
}
function isHiddenPath(path) {
  return path.startsWith(".") || path.includes("/.");
}
async function ensureFolder(...parts) {
  const path = joinPath(...parts);
  if (!await exists(path))
    await mkdir(path, { recursive: true });
  return path;
}
async function ensureFolderForFile(...parts) {
  const path = dirname(joinPath(...parts));
  if (!await exists(path))
    await mkdir(path, { recursive: true });
  return path;
}
async function removeFolder(...parts) {
  const path = joinPath(...parts);
  if (await exists(path))
    await rm(path, { recursive: true });
  return path;
}
async function readText(...parts) {
  const path = joinPath(...parts);
  if (await exists(path))
    return await readFile(path, "utf-8");
}
async function writeText(path, content, createFolders = false) {
  if (createFolders)
    await ensureFolderForFile(path);
  await writeFile(path, content, "utf-8");
}
async function writeData(path, content, createFolders = false) {
  if (createFolders)
    await ensureFolderForFile(path);
  const data = isUint8Array(content) ? content : JSON.stringify(content);
  await writeFile(path, data);
}

export {
  toHumanReadableFilePath,
  exists,
  isHiddenPath,
  ensureFolder,
  ensureFolderForFile,
  removeFolder,
  readText,
  writeText,
  writeData
};
//# sourceMappingURL=chunk-72CYVQ2Y.js.map