import {
  createPromise
} from "./chunk-FSDCRQB3.js";

// src/common/msg/rpc.ts
var rpcCounter = 1;
var defaultSerialize = (i) => i;
var defaultDeserialize = defaultSerialize;
function setupRPCBasic(options, functions, eventNames = []) {
  const {
    log,
    post,
    on,
    serialize = defaultSerialize,
    deserialize = defaultDeserialize,
    timeout = 6e4,
    onError,
    onTimeoutError,
    onlyEvents = false
  } = options;
  const rpcPromiseMap = /* @__PURE__ */ new Map();
  on(async (data) => {
    try {
      const msg = await deserialize(data);
      const mode = msg?.[0];
      const id = mode === 2 /* event */ ? 0 : msg?.[1];
      const [method, ...args] = msg.slice(mode === 2 /* event */ ? 1 : 2);
      if (mode === 1 /* request */ || mode === 2 /* event */) {
        let result, error;
        if (method != null) {
          try {
            const fn = functions[method];
            result = await fn(...args);
          } catch (e) {
            error = String(e);
          }
        } else {
          error = "Method implementation missing";
        }
        if (error) {
          log?.warn("error", msg, error);
          onError?.(error, method ?? "", args);
        }
        if (id > 0) {
          const data2 = await serialize(error ? [4 /* reject */, id, error] : [3 /* resolve */, id, result]);
          await post(data2);
        }
      } else if (id) {
        const promise = rpcPromiseMap.get(id);
        if (promise != null) {
          clearTimeout(promise.timeoutId);
          if (mode === 4 /* reject */)
            promise.reject(method);
          else
            promise.resolve(method);
        }
        rpcPromiseMap.delete(id);
      }
    } catch (err) {
      log?.warn("Error on handling RPC data. Invalid?", err, data);
    }
  });
  const proxyHandler = {
    get(_, method) {
      const sendEvent = async (...args) => await post(await serialize([2 /* event */, method, ...args]));
      if (onlyEvents || eventNames.includes(method)) {
        sendEvent.asEvent = sendEvent;
        return sendEvent;
      }
      const sendCall = async (...args) => {
        const [promise, resolve, reject] = createPromise();
        const id = rpcCounter++;
        let timeoutId;
        if (timeout >= 0) {
          timeoutId = setTimeout(() => {
            try {
              onTimeoutError?.(method, args);
              throw new Error(`rpc timeout on calling "${method}"`);
            } catch (e) {
              reject(e);
            }
            rpcPromiseMap.delete(id);
          }, timeout).unref?.();
        }
        rpcPromiseMap.set(id, { resolve, reject, timeoutId });
        const data = await serialize([1 /* request */, id, method, ...args]);
        await post(data);
        return promise;
      };
      sendCall.asEvent = sendEvent;
      return sendCall;
    }
  };
  return { post, serialize, rpcPromiseMap, proxyHandler };
}
function useRPC(functions, options) {
  const { eventNames = [] } = options;
  const { proxyHandler } = setupRPCBasic(options, functions, eventNames);
  return new Proxy({}, proxyHandler);
}
function useRPCHub(options) {
  const eventNames = [];
  const functions = {};
  const { proxyHandler } = setupRPCBasic(options, functions);
  function createRPCProxy() {
    return new Proxy({}, proxyHandler);
  }
  return function(additionalFunctions, additionalEventNames = []) {
    Object.assign(functions, additionalFunctions ?? {});
    eventNames.push(...additionalEventNames);
    return createRPCProxy();
  };
}

export {
  useRPC,
  useRPCHub
};
//# sourceMappingURL=chunk-IQFZHKL7.js.map