import {
  toCamelCase
} from "./chunk-7NSVDPHN.js";

// src/node/args.ts
import process from "node:process";
function parseArgs(config = {}) {
  const {
    args = process.argv.slice(1),
    alias = {},
    normalize = toCamelCase,
    booleanArgs = [],
    listArgs = [],
    numberArgs = []
  } = config;
  const nameToAlias = Object.entries(alias).reduce((map, curr) => {
    let [name, values] = curr;
    if (typeof values === "string")
      values = [values];
    for (const value of values)
      map[normalize(value)] = normalize(name);
    return map;
  }, {});
  const opts = {
    _: []
  };
  function setOpt(name, value) {
    if (opts[name] == null)
      opts[name] = value;
    else if (typeof opts[name] === "boolean")
      opts[name] = value;
    else if (Array.isArray(opts[name]))
      opts[name].push(value);
    else
      opts[name] = [opts[name], value];
  }
  const argList = [...args];
  let arg;
  while (arg = argList.shift()) {
    let value;
    if (/^--?/.test(arg)) {
      let key = arg.replace(/^--?/, "");
      if (arg.includes("=")) {
        const [name, valuePart] = key.split("=", 2);
        key = name.trim();
        value = valuePart.trim();
      }
      key = normalize(key);
      key = nameToAlias[key] ?? key;
      if (booleanArgs.includes(key)) {
        setOpt(key, true);
      } else {
        value = value ?? argList.shift() ?? "";
        if (numberArgs.includes(key))
          value = Number(value ?? 0);
        if (listArgs.includes(key)) {
          if (Array.isArray(opts[key]))
            opts[key].push(value);
          else
            opts[key] = [value];
        } else {
          setOpt(key, value);
        }
      }
    } else {
      opts._.push(arg);
    }
  }
  return opts;
}

export {
  parseArgs
};
//# sourceMappingURL=chunk-O5NWNSUF.js.map