"use strict";



















var _chunkCEXYDYSHcjs = require('../../chunk-CEXYDYSH.cjs');
require('../../chunk-PJXRDQ2A.cjs');
require('../../chunk-6T6PI6XG.cjs');

// src/common/data/array.spec.ts
describe("array", () => {
  it("should remove items", () => {
    const r = _chunkCEXYDYSHcjs.arrayRemoveElement.call(void 0, [1, 2, 3, 2, 4], 2);
    expect(r).toEqual([1, 3, 4]);
  });
  it("should set in place items", () => {
    const r = [1, 2, 3];
    _chunkCEXYDYSHcjs.arraySetArrayInPlace.call(void 0, r, [9, 8, 7]);
    expect(r).toEqual([9, 8, 7]);
  });
  it("should intersect", () => {
    expect(_chunkCEXYDYSHcjs.arrayIntersection.call(void 0, [1, 1, 2, 2, 3], [2, 2, 3, 5, 6])).toEqual([2, 3]);
    expect(_chunkCEXYDYSHcjs.arraySymmetricDifference.call(void 0, [1, 1, 2, 2, 3], [2, 2, 3, 5, 6])).toEqual([
      1,
      5,
      6
    ]);
    expect(_chunkCEXYDYSHcjs.arrayUnion.call(void 0, [1, 1, 2, 2, 3], [2, 2, 3, 5, 6], [7, 8])).toEqual([
      1,
      2,
      3,
      5,
      6,
      7,
      8
    ]);
    expect(_chunkCEXYDYSHcjs.arrayMinus.call(void 0, [1, 1, 2, 2, 3], [2, 2, 3, 5, 6])).toEqual([1]);
  });
  it("should sort", () => {
    const a = [9, 2, 1, 11, 8];
    expect(_chunkCEXYDYSHcjs.arraySorted.call(void 0, a, (l, r) => l - r)).toEqual([1, 2, 8, 9, 11]);
    expect(_chunkCEXYDYSHcjs.arraySortedNumbers.call(void 0, a)).toEqual([1, 2, 8, 9, 11]);
    expect(_chunkCEXYDYSHcjs.arraySorted.call(void 0, a)).toEqual([1, 2, 8, 9, 11]);
    expect(a).toEqual([9, 2, 1, 11, 8]);
  });
  it("should filter in place", () => {
    const array = [1, 2, 3, 4, 5, 6, 7, 8, 9];
    _chunkCEXYDYSHcjs.arrayFilterInPlace.call(void 0, array, (el) => el % 2 === 0);
    expect(array).toEqual([2, 4, 6, 8]);
    _chunkCEXYDYSHcjs.arrayToggleInPlace.call(void 0, array, 2);
    expect(array).toEqual([4, 6, 8]);
    _chunkCEXYDYSHcjs.arrayToggleInPlace.call(void 0, array, 2);
    expect(array).toEqual([4, 6, 8, 2]);
    _chunkCEXYDYSHcjs.arrayFilterInPlace.call(void 0, array, () => false);
    expect(array).toEqual([]);
  });
  it("should compare arrays", () => {
    expect(_chunkCEXYDYSHcjs.arrayIsEqual.call(void 0, [1, 2], [2, 1])).toBe(false);
    expect(_chunkCEXYDYSHcjs.arrayIsEqual.call(void 0, [1, 2], [1, 2])).toBe(true);
    expect(_chunkCEXYDYSHcjs.arrayIsEqual.call(void 0, [1, 2], [1, 2, void 0])).toBe(false);
    expect(_chunkCEXYDYSHcjs.arrayIsEqual.call(void 0, [1, 2], [1, 2, 3])).toBe(false);
    expect(_chunkCEXYDYSHcjs.arrayIsEqual.call(void 0, [1, 2, 3], [1, 2])).toBe(false);
  });
  it("should shuffle", () => {
    expect(_chunkCEXYDYSHcjs.arrayShuffleForce.call(void 0, [1, 2, 3])).not.toEqual([1, 2, 3]);
  });
  it("should min/max", () => {
    expect(_chunkCEXYDYSHcjs.arrayMin.call(void 0, 1, [2, 3])).toBe(1);
    expect(_chunkCEXYDYSHcjs.arrayMax.call(void 0, 1, [2, 3])).toBe(3);
    expect(_chunkCEXYDYSHcjs.arrayMin.call(void 0, "1a", ["2b", "3c"])).toBe("1a");
    expect(_chunkCEXYDYSHcjs.arrayMax.call(void 0, "1a", ["2b", "3c"])).toBe("3c");
  });
  it("should sum/avg", () => {
    expect(_chunkCEXYDYSHcjs.arraySum.call(void 0, 1, [2, 3])).toBe(6);
    expect(_chunkCEXYDYSHcjs.arrayAvg.call(void 0, 1, [2, 3])).toBe(2);
  });
  it("should flatten", () => {
    expect(_chunkCEXYDYSHcjs.arrayFlatten.call(void 0, 1, 2, [3, [4, 5]], 6)).toEqual([1, 2, 3, 4, 5, 6]);
  });
  it("should create array", () => {
    expect(_chunkCEXYDYSHcjs.createArray.call(void 0, 10, (i) => i + 2)).toEqual([
      2,
      3,
      4,
      5,
      6,
      7,
      8,
      9,
      10,
      11
    ]);
    expect(_chunkCEXYDYSHcjs.createArray.call(void 0, 3)).toEqual([void 0, void 0, void 0]);
    expect(_chunkCEXYDYSHcjs.createArray.call(void 0, 3, "hello")).toEqual(["hello", "hello", "hello"]);
    expect(_chunkCEXYDYSHcjs.createArray.call(void 0, )).toEqual([]);
  });
  it("should create batches", () => {
    expect(_chunkCEXYDYSHcjs.arrayBatches.call(void 0, [1, 2, 3, 4, 5, 6, 7], 2)).toEqual([
      [1, 2],
      [3, 4],
      [5, 6],
      [7]
    ]);
  });
});
//# sourceMappingURL=array.spec.cjs.map