type Primitive = null | undefined | string | number | boolean | symbol | bigint;
declare function isObject(obj: unknown): obj is object;
/** Something like number, string, boolean */
declare function isPrimitive(obj: unknown): obj is Primitive;
declare function isArray(obj: unknown): obj is Array<any>;
/** Object that is not an array. But could also be an object defined by a class. */
declare function isRecord(obj: unknown): obj is Record<string, any>;
/** Just data, like constructed via `{...}`. */
declare function isRecordPlain(obj: unknown): obj is Record<string, any>;
declare function isString(obj: unknown): obj is string;
declare function isNumber(obj: unknown): obj is number;
declare function isInteger(obj: unknown): obj is number;
/** Integer with full precision i.e. its value is in the signed 53 bit range.  */
declare function isSafeInteger(obj: unknown): obj is number;
declare function isBoolean(obj: unknown): obj is boolean;
/** @deprecated use `isNull` */
declare function isNullOrUndefined(obj: unknown): obj is null | undefined;
declare function isNull(obj: unknown): obj is null | undefined;
declare function isUint8Array(obj: unknown): obj is Uint8Array;
/** Not `null` or `undefined`, use like `.filter(isNotNull)` */
declare function isNotNull<T>(value: T | null | undefined): value is T;
/** Empty means `null` or `undefined` or object or array without items, use like `.filter(isEmpty)` */
declare function isEmpty<T>(value: T | null | undefined): value is T;
/** Not `null` or `undefined` or object or array without items, use like `.filter(isNotEmpty)` */
declare function isNotEmpty<T>(value: T | null | undefined): value is T;
/**
 * Not `null` or `undefined` or `false`, use like `.filter(isValue)`.
 * Usefull e.g. on conditional list: `[x && 'value', ...]`
 */
declare function isValue<T>(value: T | null | undefined | boolean): value is T;
/**
 * Not `null` or `undefined` or `false`, use like `.filter(isValue)`.
 * Usefull e.g. on conditional list: `[x && 'value', ...]`
 */
declare function isTruthy<T>(value: T | null | undefined | boolean): value is T;

export { type Primitive, isArray, isBoolean, isEmpty, isInteger, isNotEmpty, isNotNull, isNull, isNullOrUndefined, isNumber, isObject, isPrimitive, isRecord, isRecordPlain, isSafeInteger, isString, isTruthy, isUint8Array, isValue };
