import { DisposerFunction, Disposer } from './dispose-types.cjs';
import { UseDisposeConfig } from './dispose-defer.cjs';
import { LoggerInterface } from './log/log-base.cjs';

type TimerExecFunction = () => void | Promise<void>;
declare function useTimeout(fn: TimerExecFunction, timeout?: number): DisposerFunction;
declare function useInterval(fn: TimerExecFunction, interval: number): DisposerFunction;
/** The interval starts only, when the function is finished. */
declare function useIntervalPause(fn: TimerExecFunction, interval: number, immediately?: boolean): DisposerFunction;
declare function useEventListener(emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]): DisposerFunction;
declare function useEventListenerOnce(emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]): DisposerFunction;
/** Like useDispose but with shorthands for emitter and timers */
declare function useDisposeWithUtils(config?: string | UseDisposeConfig | LoggerInterface): ((strictSync?: boolean) => void | Promise<any>) & {
    disposed: number;
    add: (obj?: Disposer | undefined) => DisposerFunction | undefined;
    remove: (disposable: Disposer) => void | Promise<void>;
    track: (obj?: Disposer | undefined) => DisposerFunction | undefined;
    untrack: (disposable: Disposer) => void | Promise<void>;
    dispose: (strictSync?: boolean) => void | Promise<any>;
    disposeSync: () => void;
    sync: () => void;
    exec: (strictSync?: boolean) => void | Promise<any>;
    getSize(): number;
    isDisposed(): boolean;
} & {
    timeout: (fn: TimerExecFunction, timeout?: number) => DisposerFunction | undefined;
    interval: (fn: TimerExecFunction, interval?: number) => DisposerFunction | undefined;
    intervalPause: (fn: TimerExecFunction, interval?: number) => DisposerFunction | undefined;
    on: (emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]) => DisposerFunction | undefined;
    once: (emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]) => DisposerFunction | undefined;
};
type UseDisposeWithUtils = ReturnType<typeof useDisposeWithUtils>;

export { type TimerExecFunction, type UseDisposeWithUtils, useDisposeWithUtils, useEventListener, useEventListenerOnce, useInterval, useIntervalPause, useTimeout };
