"use strict";


var _chunkQLGR2XSScjs = require('../../chunk-QLGR2XSS.cjs');


var _chunkQYCE2TUJcjs = require('../../chunk-QYCE2TUJ.cjs');

// src/common/exec/throttle-debounce.spec.ts
describe("throttle", () => {
  it("should throttle correctly", async () => {
    let ctr = 0;
    expect(ctr).toBe(0);
    const fn = _chunkQLGR2XSScjs.throttle.call(void 0, () => ctr++, { delay: 100 });
    expect(ctr).toBe(0);
    fn();
    expect(ctr).toBe(1);
    fn();
    fn();
    expect(ctr).toBe(1);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 50);
    expect(ctr).toBe(1);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
    expect(ctr).toBe(2);
    fn();
    expect(ctr).toBe(2);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
    expect(ctr).toBe(3);
    fn();
    fn.cancel();
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
    expect(ctr).toBe(3);
  });
  it("should debounce correctly", async () => {
    let ctr = 0;
    expect(ctr).toBe(0);
    const fn = _chunkQLGR2XSScjs.debounce.call(void 0, () => ctr++, { delay: 100 });
    expect(ctr).toBe(0);
    fn();
    fn();
    expect(ctr).toBe(0);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 50);
    fn();
    expect(ctr).toBe(0);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 50);
    fn();
    expect(ctr).toBe(0);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 50);
    fn();
    expect(ctr).toBe(0);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 110);
    expect(ctr).toBe(1);
    fn();
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 110);
    expect(ctr).toBe(2);
  });
  it("should throttle with least args", async () => {
    let r = 0;
    const fn = _chunkQLGR2XSScjs.throttle.call(void 0, 
      (v) => {
        r = v;
      },
      { delay: 50 }
    );
    fn(1);
    expect(r).toBe(1);
    fn(2);
    expect(r).toBe(1);
    fn(3);
    fn(4);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
    expect(r).toBe(4);
  });
  it("should debounce long running promise", async () => {
    let r = 0;
    const fn = _chunkQLGR2XSScjs.debounce.call(void 0, 
      async (v) => {
        await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
        r = v;
      },
      { delay: 50 }
    );
    expect(r).toBe(0);
    void fn(1);
    expect(r).toBe(0);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 50);
    expect(r).toBe(0);
    void fn(2);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 150);
    void fn(3);
    expect(r).toBe(0);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 150);
    expect(r).toBe(1);
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 300);
    expect(r).toBe(3);
  });
});
//# sourceMappingURL=throttle-debounce.spec.cjs.map